package com.yunzhi.marketing.redpack.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.redpack.entity.TaOrgAccountCertificate;
import com.yunzhi.marketing.redpack.service.ITaOrgAccountCertificateService;

/**
 * <p>
    * 账户相关凭证  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-06-03
 */
@RestController
@RequestMapping("/")
public class TaOrgAccountCertificateController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOrgAccountCertificateController.class);

    @Autowired
    public ITaOrgAccountCertificateService iTaOrgAccountCertificateService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taOrgAccountCertificate",method= RequestMethod.GET)
    public ResponseBean taOrgAccountCertificateList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                    @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaOrgAccountCertificate> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaOrgAccountCertificate> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaOrgAccountCertificate> result = iTaOrgAccountCertificateService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountCertificateList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taOrgAccountCertificate 实体对象
     * @return
     */
    @RequestMapping(value="/taOrgAccountCertificate",method= RequestMethod.POST)
    public ResponseBean taOrgAccountCertificateAdd(@RequestBody TaOrgAccountCertificate taOrgAccountCertificate){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaOrgAccountCertificateService.save(taOrgAccountCertificate)){
                responseBean.addSuccess(taOrgAccountCertificate);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountCertificateAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taOrgAccountCertificate/{id}", method= RequestMethod.DELETE)
    public ResponseBean taOrgAccountCertificateDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaOrgAccountCertificateService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountCertificateDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taOrgAccountCertificate 实体对象
     * @return
     */
    @RequestMapping(value="/taOrgAccountCertificate/{id}",method= RequestMethod.PUT)
    public ResponseBean taOrgAccountCertificateUpdate(@PathVariable Integer id,
                                        @RequestBody TaOrgAccountCertificate taOrgAccountCertificate){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaOrgAccountCertificateService.updateById(taOrgAccountCertificate)){
                responseBean.addSuccess(taOrgAccountCertificate);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountCertificateUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taOrgAccountCertificate/{id}",method= RequestMethod.GET)
    public ResponseBean taOrgAccountCertificateGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaOrgAccountCertificateService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taOrgAccountCertificateDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
